@@ -40,24 +40,29 @@ from .standard import ManufacturerData, ManufacturerDataField
 __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_BLE.git"
 
-_MANUFACTURING_DATA_ADT = const(0xff)
+_MANUFACTURING_DATA_ADT = const(0xFF)
 _ADAFRUIT_COMPANY_ID = const(0x0822)
 _COLOR_DATA_ID = const(0x0000)
 
 
 class AdafruitColor(Advertisement):
     """Broadcast a single RGB color."""
+
     # This prefix matches all
-    prefix = struct.pack("<BBHBH",
-                         0x6,
-                         _MANUFACTURING_DATA_ADT,
-                         _ADAFRUIT_COMPANY_ID,
-                         struct.calcsize("<HI"),
-                         _COLOR_DATA_ID)
-    manufacturer_data = LazyObjectField(ManufacturerData,
-                                        "manufacturer_data",
-                                        advertising_data_type=_MANUFACTURING_DATA_ADT,
-                                        company_id=_ADAFRUIT_COMPANY_ID,
-                                        key_encoding="<H")
+    prefix = struct.pack(
+        "<BBHBH",
+        0x6,
+        _MANUFACTURING_DATA_ADT,
+        _ADAFRUIT_COMPANY_ID,
+        struct.calcsize("<HI"),
+        _COLOR_DATA_ID,
+    )
+    manufacturer_data = LazyObjectField(
+        ManufacturerData,
+        "manufacturer_data",
+        advertising_data_type=_MANUFACTURING_DATA_ADT,
+        company_id=_ADAFRUIT_COMPANY_ID,
+        key_encoding="<H",
+    )
     color = ManufacturerDataField(_COLOR_DATA_ID, "<I")
     """Color to broadcast as RGB integer."""
